From b8eb3e6c31d50f1e2d14e0f4996cc58debdc6aac Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter_e@gmx.net>
Date: Tue, 30 Aug 2016 12:00:00 -0400
Subject: [PATCH 15/27] Fix function prototypes for C++

C++ needs to have the right number of arguments in function signatures.
---
 src/backend/nodes/nodeFuncs.c | 28 ++++++++++++++--------------
 src/include/nodes/nodeFuncs.h | 20 ++++++++++----------
 2 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/src/backend/nodes/nodeFuncs.c b/src/backend/nodes/nodeFuncs.c
index 3997441..311b86d 100644
--- a/src/backend/nodes/nodeFuncs.c
+++ b/src/backend/nodes/nodeFuncs.c
@@ -28,10 +28,10 @@
 static bool expression_returns_set_walker(Node *node, void *context);
 static int	leftmostLoc(int loc1, int loc2);
 static bool fix_opfuncids_walker(Node *node, void *context);
-static bool planstate_walk_subplans(List *plans, bool (*walker) (),
+static bool planstate_walk_subplans(List *plans, bool (*walker) (void *, void *),
 												void *context);
 static bool planstate_walk_members(List *plans, PlanState **planstates,
-					   bool (*walker) (), void *context);
+								   bool (*walker) (void *, void *), void *context);
 
 
 /*
@@ -1849,7 +1849,7 @@ check_functions_in_node(Node *node, check_function_callback checker,
 
 bool
 expression_tree_walker(Node *node,
-					   bool (*walker) (),
+					   bool (*walker) (void *, void *),
 					   void *context)
 {
 	ListCell   *temp;
@@ -2236,7 +2236,7 @@ expression_tree_walker(Node *node,
  */
 bool
 query_tree_walker(Query *query,
-				  bool (*walker) (),
+				  bool (*walker) (void *, void *),
 				  void *context,
 				  int flags)
 {
@@ -2280,7 +2280,7 @@ query_tree_walker(Query *query,
  */
 bool
 range_table_walker(List *rtable,
-				   bool (*walker) (),
+				   bool (*walker) (void *, void *),
 				   void *context,
 				   int flags)
 {
@@ -2395,7 +2395,7 @@ range_table_walker(List *rtable,
 
 Node *
 expression_tree_mutator(Node *node,
-						Node *(*mutator) (),
+						Node *(*mutator) (void *, void *),
 						void *context)
 {
 	/*
@@ -3038,7 +3038,7 @@ expression_tree_mutator(Node *node,
  */
 Query *
 query_tree_mutator(Query *query,
-				   Node *(*mutator) (),
+				   Node *(*mutator) (void *, void *),
 				   void *context,
 				   int flags)
 {
@@ -3077,7 +3077,7 @@ query_tree_mutator(Query *query,
  */
 List *
 range_table_mutator(List *rtable,
-					Node *(*mutator) (),
+					Node *(*mutator) (void *, void *),
 					void *context,
 					int flags)
 {
@@ -3144,7 +3144,7 @@ range_table_mutator(List *rtable,
  */
 bool
 query_or_expression_tree_walker(Node *node,
-								bool (*walker) (),
+								bool (*walker) (void *, void *),
 								void *context,
 								int flags)
 {
@@ -3167,7 +3167,7 @@ query_or_expression_tree_walker(Node *node,
  */
 Node *
 query_or_expression_tree_mutator(Node *node,
-								 Node *(*mutator) (),
+								 Node *(*mutator) (void *, void *),
 								 void *context,
 								 int flags)
 {
@@ -3198,7 +3198,7 @@ query_or_expression_tree_mutator(Node *node,
  */
 bool
 raw_expression_tree_walker(Node *node,
-						   bool (*walker) (),
+						   bool (*walker) (void *, void *),
 						   void *context)
 {
 	ListCell   *temp;
@@ -3638,7 +3638,7 @@ raw_expression_tree_walker(Node *node,
  */
 bool
 planstate_tree_walker(PlanState *planstate,
-					  bool (*walker) (),
+					  bool (*walker) (void *, void *),
 					  void *context)
 {
 	Plan	   *plan = planstate->plan;
@@ -3722,7 +3722,7 @@ planstate_tree_walker(PlanState *planstate,
  */
 static bool
 planstate_walk_subplans(List *plans,
-						bool (*walker) (),
+						bool (*walker) (void *, void *),
 						void *context)
 {
 	ListCell   *lc;
@@ -3748,7 +3748,7 @@ planstate_walk_subplans(List *plans,
  */
 static bool
 planstate_walk_members(List *plans, PlanState **planstates,
-					   bool (*walker) (), void *context)
+					   bool (*walker) (void *, void *), void *context)
 {
 	int			nplans = list_length(plans);
 	int			j;
diff --git a/src/include/nodes/nodeFuncs.h b/src/include/nodes/nodeFuncs.h
index 97af142..82add17 100644
--- a/src/include/nodes/nodeFuncs.h
+++ b/src/include/nodes/nodeFuncs.h
@@ -50,31 +50,31 @@ extern void set_sa_opfuncid(ScalarArrayOpExpr *opexpr);
 extern bool check_functions_in_node(Node *node, check_function_callback checker,
 						void *context);
 
-extern bool expression_tree_walker(Node *node, bool (*walker) (),
+extern bool expression_tree_walker(Node *node, bool (*walker) (void *, void *),
 											   void *context);
-extern Node *expression_tree_mutator(Node *node, Node *(*mutator) (),
+extern Node *expression_tree_mutator(Node *node, Node *(*mutator) (void *, void *),
 												 void *context);
 
-extern bool query_tree_walker(Query *query, bool (*walker) (),
+extern bool query_tree_walker(Query *query, bool (*walker) (void *, void *),
 										  void *context, int flags);
-extern Query *query_tree_mutator(Query *query, Node *(*mutator) (),
+extern Query *query_tree_mutator(Query *query, Node *(*mutator) (void *, void *),
 											 void *context, int flags);
 
-extern bool range_table_walker(List *rtable, bool (*walker) (),
+extern bool range_table_walker(List *rtable, bool (*walker) (void *, void *),
 										   void *context, int flags);
-extern List *range_table_mutator(List *rtable, Node *(*mutator) (),
+extern List *range_table_mutator(List *rtable, Node *(*mutator) (void *, void *),
 											 void *context, int flags);
 
-extern bool query_or_expression_tree_walker(Node *node, bool (*walker) (),
+extern bool query_or_expression_tree_walker(Node *node, bool (*walker) (void *, void *),
 												   void *context, int flags);
-extern Node *query_or_expression_tree_mutator(Node *node, Node *(*mutator) (),
+extern Node *query_or_expression_tree_mutator(Node *node, Node *(*mutator) (void *, void *),
 												   void *context, int flags);
 
-extern bool raw_expression_tree_walker(Node *node, bool (*walker) (),
+extern bool raw_expression_tree_walker(Node *node, bool (*walker) (void *, void *),
 												   void *context);
 
 struct PlanState;
-extern bool planstate_tree_walker(struct PlanState *planstate, bool (*walker) (),
+extern bool planstate_tree_walker(struct PlanState *planstate, bool (*walker) (void *, void *),
 											  void *context);
 
 #endif   /* NODEFUNCS_H */
-- 
2.9.3

